@@ -9,10 +9,12 @@ try:
 except Exception:
     __version__ = ""
 
+from davinci_functions._function import function
 from davinci_functions._judge import judge
 from davinci_functions._list import list
 
 __all__ = [
+    "function",
     "judge",
     "list",
 ]
